EXPORTS
	??0CLcfRequestor@@QAE@ABV0@@Z @ 1 NONAME ; CLcfRequestor::CLcfRequestor(class CLcfRequestor const &)
	??1CLcfNotifierManager@@UAE@XZ @ 2 NONAME ; CLcfNotifierManager::~CLcfNotifierManager(void)
	??1CLcfPluginDiagnostics@@UAE@XZ @ 3 NONAME ; CLcfPluginDiagnostics::~CLcfPluginDiagnostics(void)
	??1CLcfRequestor@@UAE@XZ @ 4 NONAME ; CLcfRequestor::~CLcfRequestor(void)
	??4CLcfRequestor@@QAEAAV0@ABV0@@Z @ 5 NONAME ; class CLcfRequestor & CLcfRequestor::operator=(class CLcfRequestor const &)
	?AddRequestorLD@CLcfPluginDiagnostics@@QAEXPAVCLcfRequestor@@@Z @ 6 NONAME ; void CLcfPluginDiagnostics::AddRequestorLD(class CLcfRequestor *)
	?AppendDiagnosticsL@CLcfNotifierManager@@QAEXPBVCLcfPluginDiagnostics@@@Z @ 7 NONAME ; void CLcfNotifierManager::AppendDiagnosticsL(class CLcfPluginDiagnostics const *)
	?ClearAllInputAndOutputL@CLcfNotifierManager@@QAEXXZ @ 8 NONAME ; void CLcfNotifierManager::ClearAllInputAndOutputL(void)
	?ClearAllInputL@CLcfNotifierManager@@QAEXXZ @ 9 NONAME ; void CLcfNotifierManager::ClearAllInputL(void)
	?ClearAllOutputL@CLcfNotifierManager@@QAEXXZ @ 10 NONAME ; void CLcfNotifierManager::ClearAllOutputL(void)
	?ControlDataExists@CLcfNotifierManager@@QAEHXZ @ 11 NONAME ; int CLcfNotifierManager::ControlDataExists(void)
	?ExitReason@CLcfPluginDiagnostics@@QBE?AW4TLcfPluginExitReason@@XZ @ 12 NONAME ; enum TLcfPluginExitReason CLcfPluginDiagnostics::ExitReason(void) const
	?GetCompletionAnswer@CLcfNotifierManager@@QAEXAAW4TLcfCompletionStyle@@AAH1@Z @ 13 NONAME ; void CLcfNotifierManager::GetCompletionAnswer(enum TLcfCompletionStyle &, int &, int &)
	?GetDiagnosticsL@CLcfNotifierManager@@QAEXHAAPAVCLcfPluginDiagnostics@@@Z @ 14 NONAME ; void CLcfNotifierManager::GetDiagnosticsL(int, class CLcfPluginDiagnostics * &)
	?GetLatestDiagnosticsL@CLcfNotifierManager@@QAEXAAPAVCLcfPluginDiagnostics@@@Z @ 15 NONAME ; void CLcfNotifierManager::GetLatestDiagnosticsL(class CLcfPluginDiagnostics * &)
	?GetNotificationAnswerL@CLcfNotifierManager@@QAEXHAAW4TLcfPluginAnswer@@AAN@Z @ 16 NONAME ; void CLcfNotifierManager::GetNotificationAnswerL(int, enum TLcfPluginAnswer &, double &)
	?GetVerificationAnswerL@CLcfNotifierManager@@QAEXHAAW4TLcfPluginAnswer@@AAN@Z @ 17 NONAME ; void CLcfNotifierManager::GetVerificationAnswerL(int, enum TLcfPluginAnswer &, double &)
	?NbOfDiagnostics@CLcfNotifierManager@@QAEHXZ @ 18 NONAME ; int CLcfNotifierManager::NbOfDiagnostics(void)
	?NewL@CLcfNotifierManager@@SAPAV1@H@Z @ 19 NONAME ; class CLcfNotifierManager * CLcfNotifierManager::NewL(int)
	?NewL@CLcfPluginDiagnostics@@SAPAV1@XZ @ 20 NONAME ; class CLcfPluginDiagnostics * CLcfPluginDiagnostics::NewL(void)
	?NewL@CLcfRequestor@@SAPAV1@XZ @ 21 NONAME ; class CLcfRequestor * CLcfRequestor::NewL(void)
	?NewLC@CLcfNotifierManager@@SAPAV1@H@Z @ 22 NONAME ; class CLcfNotifierManager * CLcfNotifierManager::NewLC(int)
	?NewLC@CLcfPluginDiagnostics@@SAPAV1@XZ @ 23 NONAME ; class CLcfPluginDiagnostics * CLcfPluginDiagnostics::NewLC(void)
	?NewLC@CLcfRequestor@@SAPAV1@XZ @ 24 NONAME ; class CLcfRequestor * CLcfRequestor::NewLC(void)
	?NumberOfRequestors@CLcfPluginDiagnostics@@QBEHXZ @ 25 NONAME ; int CLcfPluginDiagnostics::NumberOfRequestors(void) const
	?RequestId@CLcfPluginDiagnostics@@QBEHXZ @ 26 NONAME ; int CLcfPluginDiagnostics::RequestId(void) const
	?RequestorL@CLcfPluginDiagnostics@@QBEPAVCLcfRequestor@@H@Z @ 27 NONAME ; class CLcfRequestor * CLcfPluginDiagnostics::RequestorL(int) const
	?RequestorLC@CLcfPluginDiagnostics@@QBEPAVCLcfRequestor@@H@Z @ 28 NONAME ; class CLcfRequestor * CLcfPluginDiagnostics::RequestorLC(int) const
	?ResetPluginL@CLcfNotifierManager@@QAEXXZ @ 29 NONAME ; void CLcfNotifierManager::ResetPluginL(void)
	?ResetRequested@CLcfNotifierManager@@QAEHXZ @ 30 NONAME ; int CLcfNotifierManager::ResetRequested(void)
	?SetCompletionCodeL@CLcfNotifierManager@@QAEXW4TLcfPluginAnswerType@@W4TLcfCompletionStyle@@HHHN@Z @ 31 NONAME ; void CLcfNotifierManager::SetCompletionCodeL(enum TLcfPluginAnswerType, enum TLcfCompletionStyle, int, int, int, double)
	?SetDefaultNotificationAnswerL@CLcfNotifierManager@@QAEXW4TLcfPluginAnswer@@N@Z @ 32 NONAME ; void CLcfNotifierManager::SetDefaultNotificationAnswerL(enum TLcfPluginAnswer, double)
	?SetDefaultVerificationAnswerL@CLcfNotifierManager@@QAEXW4TLcfPluginAnswer@@N@Z @ 33 NONAME ; void CLcfNotifierManager::SetDefaultVerificationAnswerL(enum TLcfPluginAnswer, double)
	?SetExitReason@CLcfPluginDiagnostics@@QAEXW4TLcfPluginExitReason@@@Z @ 34 NONAME ; void CLcfPluginDiagnostics::SetExitReason(enum TLcfPluginExitReason)
	?SetIsVerificationRequest@CLcfPluginDiagnostics@@QAEXH@Z @ 35 NONAME ; void CLcfPluginDiagnostics::SetIsVerificationRequest(int)
	?SetNextNotificationAnswerL@CLcfNotifierManager@@QAEXW4TLcfPluginAnswer@@N@Z @ 36 NONAME ; void CLcfNotifierManager::SetNextNotificationAnswerL(enum TLcfPluginAnswer, double)
	?SetNextVerificationAnswerL@CLcfNotifierManager@@QAEXW4TLcfPluginAnswer@@N@Z @ 37 NONAME ; void CLcfNotifierManager::SetNextVerificationAnswerL(enum TLcfPluginAnswer, double)
	?SetNotificationAnswerL@CLcfNotifierManager@@QAEXHW4TLcfPluginAnswer@@N@Z @ 38 NONAME ; void CLcfNotifierManager::SetNotificationAnswerL(int, enum TLcfPluginAnswer, double)
	?SetRequestId@CLcfPluginDiagnostics@@QAEXH@Z @ 39 NONAME ; void CLcfPluginDiagnostics::SetRequestId(int)
	?SetVerificationAnswerL@CLcfNotifierManager@@QAEXHW4TLcfPluginAnswer@@N@Z @ 40 NONAME ; void CLcfNotifierManager::SetVerificationAnswerL(int, enum TLcfPluginAnswer, double)
	?VerificationRequest@CLcfPluginDiagnostics@@QBEHXZ @ 41 NONAME ; int CLcfPluginDiagnostics::VerificationRequest(void) const

